# Descope SDK for Python

Use the Descope SDK for Python to quickly and easily add user authentication to your application or website.

The SDK supports Python 3.6 and above.

## Installing the SDK

Replace any instance of `<ProjectID>` in the code below with your company's Project ID, which can be found in the [Descope console](https://app.descope.com).

Run the following code in your project. These commands will add the Descope ExpresSDK for Python as a project dependency, and set the `DESCOPE_PROJECT_ID` variable to a valid \<ProjectID\>.

```code
pip install descope
export DESCOPE_PROJECT_ID=<ProjectID>
```

## What do you want to implement?

Click one of the following links to open the documentation for that specific functionality.

- [x] [One time passwords (OTP)](https://github.com/descope/python-sdk/blob/main/docs/otp.md)
- [x] [Magic Links](https://github.com/descope/python-sdk/blob/main/docs/magiclink.md)

## License

The Descope ExpresSDK for Python is licensed for use under the terms and conditions of the [MIT license Agreement](https://github.com/descope/python-sdk/blob/main/LICENSE).
